@@ -68,7 +68,9 @@ get_ui = function()
 		            style = 'display:inline-block;margin-bottom:0;margin-right:1em;'),
 		          withBusyIndicatorUI(actionButton('go_import_new_rules', 'import', class='btn btn-primary')),
 		          tableOutput("new_rules_preview")),
-		        id='proj_rules_tabs')),
+		        id='proj_rules_tabs'),
+		      id='proj_rules_frm'
+		      ),
 		    column(4,
 		      tags$h3('Items',style='margin-bottom:15px;'),
 		      tabsetPanel(type = 'tabs',
@@ -83,7 +85,8 @@ get_ui = function()
 		            style = 'display:inline-block;margin-bottom:0;margin-right:1em;'),
 		          withBusyIndicatorUI(actionButton('go_import_new_itemprop', 'import')),
 		          tags$div(textOutput('rules_upload_error', inline=TRUE), class='error'),
-		          tableOutput("new_itemprop_preview")))),
+		          tableOutput("new_itemprop_preview"))),
+		      id='proj_items_frm'),
 		    column(4,
 		      tags$h3('Persons',style='margin-bottom:15px;'),
 		      tabsetPanel(type = 'tabs',
@@ -97,7 +100,8 @@ get_ui = function()
 		            fileInput('person_property_file', 'Import person properties'),
 		            style = 'display:inline-block;margin-bottom:0;margin-right:1em;'),
 		          withBusyIndicatorUI(actionButton('go_import_new_personprop', 'import')),
-		          dataTableOutput("new_personprop_preview")))),
+		          dataTableOutput("new_personprop_preview"))),
+		      id='proj_persons_frm'),
 		    style='margin-left:0;')),
 		tabPanel('Data import',
 		  tags$h3('Import respons data'),
